@@ -1,7 +1,9 @@
 from models import Group
 import factory
+import random
 
 class GroupFactory(factory.DjangoModelFactory):
     FACTORY_FOR = Group
 
-    id = factory.Sequence(lambda n: n)
\ No newline at end of file
+    id = factory.Sequence(lambda n: n)
+    members_count = random.randrange(0, 10000)
\ No newline at end of file
